@@ -158,6 +158,7 @@ OptionsDialog::OptionsDialog() {
 	libraryTab.addOption(ZLResourceKey("lookInSubdirectories"), library.ScanSubdirsOption);
 	libraryTab.addOption(ZLResourceKey("collectBooksWithoutMetaInfo"), library.CollectAllBooksOption);
 	libraryTab.addOption(ZLResourceKey("downloadDirectory"), NetworkLinkCollection::Instance().DirectoryOption);
+	libraryTab.addOption(ZLResourceKey("alwaysStartInLibrary"), fbreader.AlwaysStartInLibraryOption);
 
 	myNetworkLibraryPage = new NetworkLibraryPage(myDialog->createTab(ZLResourceKey("NetworkLibrary")));
 
@@ -188,6 +189,21 @@ OptionsDialog::OptionsDialog() {
 			enableTapScrollingEntry->addDependentEntry(fingerOnlyEntry);
 			enableTapScrollingEntry->onStateChanged(enableTapScrollingEntry->initialState());
 		}
+		ZLToggleBooleanOptionEntry *dragOnlyEntry =
+			new ZLToggleBooleanOptionEntry(fbreader.TapScrollingOnDragOnlyOption);
+		scrollingTab.addOption(ZLResourceKey("dragOnly"), dragOnlyEntry);
+		enableTapScrollingEntry->addDependentEntry(dragOnlyEntry);
+		enableTapScrollingEntry->onStateChanged(enableTapScrollingEntry->initialState());
+		ZLToggleBooleanOptionEntry *variableDragEntry =
+			new ZLToggleBooleanOptionEntry(fbreader.VariableDragOption);
+		scrollingTab.addOption(ZLResourceKey("variableDrag"), variableDragEntry);
+		dragOnlyEntry->addDependentEntry(variableDragEntry);
+		dragOnlyEntry->onStateChanged(dragOnlyEntry->initialState());
+		ZLOptionEntry *variableDragLengthEntry =
+			new ZLSimpleSpinOptionEntry(fbreader.VariableDragLengthOption, 100);
+		scrollingTab.addOption(ZLResourceKey("variableDragLength"), variableDragLengthEntry);
+		variableDragEntry->addDependentEntry(variableDragLengthEntry);
+		variableDragEntry->onStateChanged(variableDragEntry->initialState());
 	}
 
 	ZLDialogContent &selectionTab = myDialog->createTab(ZLResourceKey("Selection"));
